<?php

namespace Teknisa\ACL\Controllers;

use Teknisa\Libs\Util\Environment;
use Util\Utilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Teknisa\ACL\Util\InstanceProvider;
use Teknisa\ACL\Util\Messages;
use Teknisa\ACL\Util\AclUtilities;
use Teknisa\ACL\Services\Vendedor;
use Zeedhi\Framework\DataSource\FilterCriteria;


class Operator extends Crud{

    protected $dataSourceName = "operator";

    /** @var Environment */
    protected $environment;

    public function __construct(Manager $dataSourceManager, Environment $environment) {
        $this->environment = $environment;
        parent::__construct($dataSourceManager);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $request->getFilterCriteria()->addCondition("NRORG", $this->environment->getCurrentOrganizationId());
        parent::find($request, $response);
    }

    public function saveOperator(Request $request, Response $response)
    {
        try {
            $operatorService = InstanceProvider::getService()->getOperator();
            $row = $request->getDataSet()->getRows()[0];
            $showFullOperator = $row['SHOW_FULL_OPERATOR'];
             list(
                $isNew, $operatorCode, $activeOperatorId, $activeId, $operatorName, $accessName, $operatorEmail,
                $cpf, $countryName, $countryCode, $password, $confirmPassword, $businessPartnership,
                $clientCode, $accessOperatorId,
                $selectedOrganizationNumber, $selectedBranchId, $selectedProfile, $inscriptionTypeCode, $operatorInclusionCode,
                 $oldCpf, $oldClientCode, $oldOperatorName, $idopermaster, $nrestruttrab, $idtpoperador, $administrator, $branches, $nrOrgOper,$gropor,$nrperfilacesso
            ) = $this->buildOperatorValues($row);
            if($isNew){
                $operator = $operatorService->saveOperator(
                    $operatorCode, $activeOperatorId, $activeId, $operatorName, $accessName, $operatorEmail,
                    $cpf, $countryName, $countryCode, $password, $confirmPassword, $businessPartnership,
                    $clientCode, $accessOperatorId,
                    $selectedOrganizationNumber, $selectedBranchId, $selectedProfile, $inscriptionTypeCode,
                    $operatorInclusionCode, $idopermaster, $nrestruttrab, $idtpoperador, $administrator, $branches, $nrOrgOper,  $this->environment->getCdFilial(), $showFullOperator
                );

                if($row['ADD_SELLER']){
                    $vendedor = new Vendedor();
                    $vendedor->checkVendedor($row);
                }

            } else {
                $operator = $operatorService->editOperator(
                    $operatorCode, $activeOperatorId, $activeId, $operatorName, $accessName, $operatorEmail,
                    $cpf, $countryName, $countryCode, $businessPartnership,
                    $clientCode, $accessOperatorId,
                    $selectedOrganizationNumber, $selectedBranchId, $selectedProfile, $inscriptionTypeCode,
                    $operatorInclusionCode, $oldCpf, $oldClientCode, $oldOperatorName, $idopermaster, $nrestruttrab, $idtpoperador, $nrOrgOper
                );
            }
            $operatorService->NewGrupoper( $gropor,$operator,$nrperfilacesso);


            $response->addDataSet(new DataSet('operator', [$operator]));
        } catch (\Exception $e){
            $msg = $e->getMessage();
            if(strpos($e->getMessage(), 'UN_OPERADOR')){
                $msg = Messages::ERR_EXISTS_EMAIL;
            }
            $response->setError(new Response\Error($msg, $e->getCode()));
        }
    }

    public function deleteOperator(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $operatorCode = $row[0]["CDOPERADOR"];
            InstanceProvider::getService()->getOperator()->deleteOperator($operatorCode);
        } catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findOperator(Request $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        try {
            $businessPartnership = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRPARCNEGOCIO', true);
            $operatorService = InstanceProvider::getService()->getOperator();
            $operators = $operatorService->findOperator($conditions, $page, $pageSize, $businessPartnership);
            $response->addDataSet(new DataSet('operator', $operators));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findOperatorZhuLog(Request $request, Response $response)
    {
        $request->getFilterCriteria()->addCondition("IDATIVO", 'S');
        $request->getFilterCriteria()->addCondition("IDOPERATIVO", 'A');
        $conditions = $request->getFilterCriteria()->getConditions();
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        try {
            $businessPartnership = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRPARCNEGOCIO', true);
            $operatorService = InstanceProvider::getService()->getOperator();
            $operators = $operatorService->findOperator($conditions, $page, $pageSize, $businessPartnership);
            $response->addDataSet(new DataSet('operator', $operators));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findOrganization(Request $request, Response $response)
    {
        try {
            $organization = InstanceProvider::getService()->getOperator()->findOrganization();
            $response->addDataSet(new DataSet('findOrganization', $organization));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findOrganizationZhuLog(Request $request, Response $response)
    {
        try {
            $organization = InstanceProvider::getService()->getOperator()->findOrganizationZhuLog();
            $response->addDataSet(new DataSet('organization', $organization));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findTypeAccessProfile(Request $request, Response $response)
    {
        try {
            $IdUtlPerfilFilial = $this->environment->getIdUtlPerfilFilial();
            $response->addDataSet(new DataSet('findTypeAccessProfile', array($IdUtlPerfilFilial)));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function checkIfIsAdm(Request $request, Response $response)
    {
        try {
            $row = $request->getRow();
            $accessProfilesList = implode(",", (array)$row);
            $isAdm = InstanceProvider::getService()->getOperator()->checkIfIsAdm($accessProfilesList);
            $organizationId = InstanceProvider::getEnvironment()->getOrganizationId();
            $response->addDataSet(new DataSet('administrator', array($isAdm, $organizationId)));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findPartnerAccessProfile(Request $request, Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $orderBy  = $request->getFilterCriteria()->getOrderBy();
            $partnerAccessProfile = InstanceProvider::getService()->getOperator()->findPartnerAccessProfile($conditions, $orderBy);
            $response->addDataSet(new DataSet('partnerAccessProfile', $partnerAccessProfile));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findBranchAccessProfile(Request $request, Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $orderBy  = $request->getFilterCriteria()->getOrderBy();
            $branchAccessProfile = InstanceProvider::getService()->getOperator()->findBranchAccessProfile($conditions, $orderBy);
            $response->addDataSet(new DataSet('branchAccessProfile', $branchAccessProfile));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function deletePartnerAccessProfile(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $partnerAccessProfileNumber = $row[0]["NRPERFACESSPARC"];
            $partnerAccessProfile = InstanceProvider::getService()->getOperator()->deletePartnerAccessProfile($partnerAccessProfileNumber);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteBranchAccessProfile(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $branchAccessProfileNumber = $row[0]["NRPERFILACESSO"];
            $operator = $row[0]["CDOPERADOR"];
            $branch = $row[0]["CDFILIAL"];
            $branchAccessProfileNumber = InstanceProvider::getService()->getOperator()->deleteBranchAccessProfile($branchAccessProfileNumber, $operator, $branch);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findAccessProfileByOperator(Request $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $businessPartnership = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRPARCNEGOCIO');
        try {
            $accessProfile = InstanceProvider::getService()->getOperator()->findAccessProfileByOperator($businessPartnership);
            $response->addDataSet(new DataSet('accessProfileByOperator', $accessProfile));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }


    public function findAccessProfileByControlProfile(Request $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $operador = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADOR');
        $operadorcont = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADORCONT');
        $cdfilial = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDFILIAL');

        try {
            $accessProfile = InstanceProvider::getService()->getOperator()->findAccessProfileByControlProfile($operador, $operadorcont, $cdfilial);
            $response->addDataSet(new DataSet('accessProfileByControlProfile', $accessProfile));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findUnidade(Request $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $page = $request->getFilterCriteria()->getPage();
        $pageSize = $request->getFilterCriteria()->getPageSize();
        $utlPerfilFilial = $this->environment->getIdUtlPerfilFilial();
        $operator = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADOR');

        $operatorCont = $this->environment->getCdOperador();
        try {
            $accessProfile = InstanceProvider::getService()->getOperator()->findUnidade($utlPerfilFilial, $operator, $operatorCont, $page, $pageSize);
            $response->addDataSet(new DataSet('accessProfileByControlProfile', $accessProfile));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function findUnidadeOperator(Request $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $operator = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADOR', true);
        AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDFILIAL', true);
        $showFullOperator = AclUtilities::getValueInFilterDataSourceByName($conditions, 'SHOW_FULL_OPERATOR', true);
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        $utlPerfilFilial = $this->environment->getIdUtlPerfilFilial();
        $operatorCont = $this->environment->getCdOperador();
        try {
            $nrorgoper = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRORGOPER', true);
            $isPrimary = false;
            InstanceProvider::getService()->getOperator()->findOrgOper($nrorgoper, $isPrimary, $showFullOperator);
            if($isPrimary && $utlPerfilFilial == 'S' && $showFullOperator ){
                $cdfilial = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDFILIAL');
                if($cdfilial != null){
                    $filter = "AND FILI.CDFILIAL NOT IN ('" . join("','", $cdfilial) . "')";
                } else {
                    $filter = ' ';
                }
                $branches = InstanceProvider::getService()->getOperator()->getAllBranches($page, $pageSize, $conditions, $filter);
            } else {
                $branches = InstanceProvider::getService()->getOperator()->findUnidade($utlPerfilFilial, $operator, $operatorCont, $page, $pageSize, $conditions);
            }
            $response->addDataSet(new DataSet('unidades', $branches));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function saveAccessProfileByOperator(Request $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            $isNew = $rows[0]['__is_new'];
            if($isNew){
                InstanceProvider::getService()->getOperator()->saveAccessProfileByOperator($rows);
            } else {
                $partnerAccessProfileNumber = $rows[0]['NRPERFACESSPARC'];
                $activeId = $rows[0]['IDATIVO'];
                $dtValidade = $rows[0]['DTVALIDADE'];
                InstanceProvider::getService()->getOperator()->editAccessProfileByOperator($partnerAccessProfileNumber, $activeId, $dtValidade);
                $partnerAccessProfileNumber = array('NRPERFACESSPARC' => $partnerAccessProfileNumber);
                $response->addDataSet(new DataSet('accessProfileByOperator', [$partnerAccessProfileNumber]));
            }
        } catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function saveAccessProfileByControlProfile(Request $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            $isNew = $rows[0]['__is_new'];
            if($isNew){
                InstanceProvider::getService()->getOperator()->saveAccessProfileByControlProfile($rows);
            } else {
                $accessProfileNumber = $rows[0]['NRPERFILACESSO'];
                $activeId = $rows[0]['IDATIVO'];
                $dtValidade = $rows[0]['DTVALIDADE'];
                $operador = $rows[0]['CDOPERADOR'];
                $unidade = $rows[0]['CDFILIAL'];
                InstanceProvider::getService()->getOperator()->editAccessProfileByControlProfile($accessProfileNumber,  $operador, $unidade, $activeId, $dtValidade);
                $accessProfileNumber = array('NRPERFACESSPARC' => $accessProfileNumber);
                $response->addDataSet(new DataSet('accessProfileByOperator', [$accessProfileNumber]));
            }
        } catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function deleteRelatedBranch(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $cdfilial = $row[0]["CDFILIAL"];
            $cdoperador = $row[0]["CDOPERADOR"];
            $relatedBranch = InstanceProvider::getService()->getOperator()->deleteRelatedBranch($cdfilial, $cdoperador);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function saveRelatedBranchByOperator(Request $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            $isNew = $rows[0]['__is_new'];
            if($isNew){
                InstanceProvider::getService()->getOperator()->saveRelatedBranchByOperator($rows);
            } else {
                $cdfilial = $rows[0]['CDFILIAL'];
                $cdoperador = $rows[0]['CDOPERADOR'];
                $activeId = $rows[0]['IDATIVO'];
                $dtValidade = $rows[0]['DTVALIDADE'];
                InstanceProvider::getService()->getOperator()->editRelatedBranchByOperator($cdfilial, $cdoperador, $activeId, $dtValidade);
                $cdfilial = array('CDFILIAL' => $cdfilial, 'CDOPERADOR' => $cdoperador);
                $response->addDataSet(new DataSet('relatedBranchesByOperator', [$cdfilial]));
            }
        } catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function deleteRelatedOrganization(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $nrorgrel = $row[0]["NRORGREL"];
            $cdoperador = $row[0]["CDOPERADOR"];
            $relatedBranch = InstanceProvider::getService()->getOperator()->deleteRelatedOrganization($nrorgrel, $cdoperador);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function saveRelatedOrganizationByOperator(Request $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            $isNew = $rows[0]['__is_new'];
            if($isNew){
                InstanceProvider::getService()->getOperator()->saveRelatedOrganizationByOperator($rows);
            } else {
                $nrorgrel = $rows[0]['NRORGREL'];
                $cdoperador = $rows[0]['CDOPERADOR'];
                $activeId = $rows[0]['IDATIVO'];
                InstanceProvider::getService()->getOperator()->editRelatedOrganizationByOperator($nrorgrel, $cdoperador, $activeId);
                $cdfilial = array('NRORGREL' => $nrorgrel, 'CDOPERADOR' => $cdoperador);
                $response->addDataSet(new DataSet('relatedOrganizationsByOperator', [$cdfilial]));
            }
        } catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function resetPassword(Request $request, Response $response)
    {
        try{
            $row                = $request->getDataSet()->getRows();
            $password           = $row[0]["NEW_PASSWORD"];
            $confirmPassword    = $row[0]["CONFIRM_PASSWORD"];
            $email              = $row[0]['DSEMAILOPER'];
            $cdOperador         = $row[0]['CDOPERADOR'];
            InstanceProvider::getService()->getOperator()->resetPassword($password, $confirmPassword, $email, $cdOperador);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findUserData(Request $request, Response $response)
    {
        try {
            $conditions     = $request->getFilterCriteria()->getConditions();
            $userId         = AclUtilities::getValueInFilterDataSourceByName($conditions, 'USER_ID');
            $organizationId = AclUtilities::getValueInFilterDataSourceByName($conditions, 'ORGANIZATION_ID');
            $userData       = InstanceProvider::getService()->getOperator()->findUserData($userId, $organizationId);
            $response->addDataSet(new DataSet('findUserData', $userData));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }
    public function updatePassword(Request $request, Response $response)
    {
        try{
            $row                = $request->getDataSet()->getRows();
            $password           = $row[0]['PASSWORD'];
            $newPassword        = $row[0]["NEW_PASSWORD"];
            $confirmPassword    = $row[0]["CONFIRM_PASSWORD"];
            InstanceProvider::getService()->getOperator()->updatePassword($password, $newPassword, $confirmPassword);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function uploadProfilePicture(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $imagePath = empty($row['IMAGE'][0]['path'])? null :$row['IMAGE'][0]['path'];
            $imagePath = InstanceProvider::getService()->getOperator()->uploadProfilePicture($imagePath);
            $response->addDataSet(new DataSet('uploadProfilePicture', $imagePath));
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteProfilePicture(Request\DataSet $request, Response $response)
    {
        try{
            InstanceProvider::getService()->getOperator()->deleteProfilePicture();
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function buildOperatorValues($row)
    {
        $isNew = empty($row['__is_new']) ? null : $row['__is_new'];
        $operatorCode = empty($row['CDOPERADOR']) ? null : $row['CDOPERADOR'];
        $activeOperatorId = empty($row['IDOPERATIVO']) ? null : $row['IDOPERATIVO'];
        $activeId = empty($row['IDATIVO']) ? null : $row['IDATIVO'];
        $operatorName = $row['NMOPERADOR'];
        $accessName = empty($row['NMACESSO']) ? null : $row['NMACESSO'];
        $operatorEmail = empty($row['DSEMAILOPER']) ? null : $row['DSEMAILOPER'];
        $cpf = empty($row['NRINSCRICAOPARC']) ? null : $row['NRINSCRICAOPARC'];
        $countryName = empty($row['NMPAIS']) ? null : $row['NMPAIS'];
        $countryCode = empty($row['CDPAIS']) ? null : $row['CDPAIS'];
        $password = empty($row['NEW_PASSWORD']) ? null : $row['NEW_PASSWORD'];
        $confirmPassword = empty($row['CONFIRM_PASSWORD']) ? null : $row['CONFIRM_PASSWORD'];
        $businessPartnership = empty($row['NRPARCNEGOCIO']) ? null : $row['NRPARCNEGOCIO'];
        $clientCode = empty($row['CDCLIENTE']) ? null : $row['CDCLIENTE'];
        $accessOperatorId = empty($row['IDOPERACESSO']) ? null : $row['IDOPERACESSO'];
        $selectedOrganizationNumber = empty($row['NRORGSELECIONADA']) ? null : $row['NRORGSELECIONADA'];
        $selectedBranchId = empty($row['CDFILIALSELECIONADA']) ? null : $row['CDFILIALSELECIONADA'];
        $selectedProfile = empty($row['CDPERFILSELECIONADO']) ? null : $row['CDPERFILSELECIONADO'];
        $inscriptionTypeCode = empty($row['CDTIPOINSCRICAO']) ? null : $row['CDTIPOINSCRICAO'];
        $operatorInclusionCode = empty($row['CDOPERINCLUSAO']) ? null : $row['CDOPERINCLUSAO'];
        $oldCpf = empty($row['OLDNRINSCRICAOPARC']) ? null : $row['OLDNRINSCRICAOPARC'];
        $oldClientCode = empty($row['OLDCDCLIENTE']) ? null : $row['OLDCDCLIENTE'];
        $oldOperatorName = empty($row['OLDNMOPERADOR']) ? null : $row['OLDNMOPERADOR'];
        $idopermaster = empty($row['IDOPERMASTER']) ? 'N' : $row['IDOPERMASTER'];
        $nrestruttrab = empty($row['NRESTRUTTRAB']) ? null : $row['NRESTRUTTRAB'];
        $idtpoperador = empty($row['IDTPOPERADOR']) ? null : $row['IDTPOPERADOR'];
        $administrator = empty($row['ADMINISTRATOR']) ? null : $row['ADMINISTRATOR'];
        $branches = empty($row['FILIALNM']) ? null : $row['FILIALNM'];
        $nrOrgOper = empty($row['NRORGOPER']) ? null : $row['NRORGOPER'];
        $gropor = empty($row['grupo_operadores']) ? null : $row['grupo_operadores'];
        $nrperfilacesso = empty($row['NRPERFILACESSO']) ? null : $row['NRPERFILACESSO'];
        return array(
            $isNew, $operatorCode, $activeOperatorId, $activeId, $operatorName, $accessName, $operatorEmail,
            $cpf, $countryName, $countryCode, $password, $confirmPassword, $businessPartnership,
            $clientCode, $accessOperatorId,
            $selectedOrganizationNumber, $selectedBranchId, $selectedProfile, $inscriptionTypeCode,
            $operatorInclusionCode, $oldCpf, $oldClientCode, $oldOperatorName, $idopermaster, $nrestruttrab,
            $idtpoperador, $administrator, $branches, $nrOrgOper,$gropor,$nrperfilacesso
        );
    }

    public function createBusinessPartnership(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $operatorName = $row['NMOPERADOR'];
            $cpf = empty($row['NRINSCRICAOPARC']) ? null : $row['NRINSCRICAOPARC'];
            $activeId = empty($row['IDATIVO']) ? null : $row['IDATIVO'];
            $operatorInclusionCode = empty($row['CDOPERINCLUSAO']) ? null : $row['CDOPERINCLUSAO'];
            $inscriptionTypeCode = empty($row['CDTIPOINSCRICAO']) ? null : $row['CDTIPOINSCRICAO'];
            $operatorCode = empty($row['CDOPERADOR']) ? null : $row['CDOPERADOR'];

            $businessPartnership = InstanceProvider::getService()->getOperator()->setBusinessPartnership($operatorName, $cpf, $activeId, $operatorInclusionCode, $inscriptionTypeCode, $operatorCode);
            $response->addDataSet(new DataSet('createBusinessPartnership', [$businessPartnership]));
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findOrgOper(Request\Filter $request, Response $response)
    {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $nrorgoper = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRORGOPER', true);
            $organizations = InstanceProvider::getService()->getOperator()->findOrgOper($nrorgoper, $isPrimary);
            $response->addDataSet(new DataSet('findOrgOper', $organizations));
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }


    /**
     * @param Request\Filter $request
     * @param Response $response
     * @throws \Exception
     */
    public function findFilioper(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $orderBy    = $request->getFilterCriteria()->getOrderBy();
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        $data = InstanceProvider::getService()->getOperator()->findFilioper($conditions, $orderBy, $page, $pageSize);
        $response->addDataSet(new DataSet('findPerfAcessParcOperador', $data));
    }

    public function deleteFilioper(Request\DataSet $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            foreach ($rows as $row) {
                $cdOperador = $row["CDOPERADOR"];
                $cdFilial = $row["CDFILIAL"];
                $nrOrg = $row["NRORGFILIAL"] ? $row["NRORGFILIAL"] : InstanceProvider::getLibEnvironment()->getCurrentOrganizationId();
                InstanceProvider::getService()->getOperator()->deleteFilioper($cdOperador, $cdFilial, $nrOrg);
            }
        }catch (\Exception $e){
                $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findParamGeral(Request $request, Response $response)
    {
        try {
            $paramGeral = InstanceProvider::getService()->getOperator()->findParamGeral();
            $response->addDataSet(new DataSet('paramgeral', $paramGeral));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }

    public function validateNovoCodigo(Request $request, Response $response)
    {
        try {
            $novoCodigo = InstanceProvider::getService()->getOperator()->validateNovoCodigo();
            $response->addDataSet(new DataSet('novoCodigo', [$novoCodigo]));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }


    public function getProfileCanBeEdit(DTO\Request\Filter $request, DTO\Response $response)
    {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $operatorCont         = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADORCONT');
            $operator     = AclUtilities::getValueInFilterDataSourceByName($conditions, 'CDOPERADOR');
            $nrorg            = AclUtilities::getValueInFilterDataSourceByName($conditions, 'NRORG');
            $return = InstanceProvider::getService()->getOperator()->getProfileCanBeEdit($operator, $operatorCont, $nrorg);
            $response->addDataSet(new DataSet('getProfileCanBeEdit', array(!empty($return))));
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
